==> cloudformation-1.60.0-sources.jar: software/amazon/awscdk/services/cloudformation/NestedStackProps.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * Initialization props for the `NestedStack` construct.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.363Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.NestedStackProps")
@software.amazon.jsii.Jsii.Proxy(NestedStackProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NestedStackProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Simple Notification Service (SNS) topics to publish stack related events.
     * <p>
     * Default: - notifications are not sent for this stack.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.sns.ITopic> getNotifications() {
        return null;
    }

    /**
     * The set value pairs that represent the parameters passed to CloudFormation when this nested stack is created.
     * <p>
     * Each parameter has a name corresponding
     * to a parameter defined in the embedded template and a value representing
     * the value that you want to set for the parameter.
     * <p>
     * The nested stack construct will automatically synthesize parameters in order
     * to bind references from the parent stack(s) into the nested stack.
     * <p>
     * Default: - no user-defined parameters are passed to the nested stack
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getParameters() {
        return null;
    }

    /**
     * The length of time that CloudFormation waits for the nested stack to reach the CREATE_COMPLETE state.
     * <p>
     * When CloudFormation detects that the nested stack has reached the
     * CREATE_COMPLETE state, it marks the nested stack resource as
     * CREATE_COMPLETE in the parent stack and resumes creating the parent stack.
     * If the timeout period expires before the nested stack reaches
     * CREATE_COMPLETE, CloudFormation marks the nested stack as failed and rolls
     * back both the nested stack and parent stack.
     * <p>
     * Default: - no timeout
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getTimeout() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NestedStackProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NestedStackProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NestedStackProps> {
        private java.util.List<software.amazon.awscdk.services.sns.ITopic> notifications;
        private java.util.Map<java.lang.String, java.lang.String> parameters;
        private software.amazon.awscdk.core.Duration timeout;

        /**
         * Sets the value of {@link NestedStackProps#getNotifications}
         * @param notifications The Simple Notification Service (SNS) topics to publish stack related events.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder notifications(java.util.List<software.amazon.awscdk.services.sns.ITopic> notifications) {
            this.notifications = notifications;
            return this;
        }

        /**
         * Sets the value of {@link NestedStackProps#getParameters}
         * @param parameters The set value pairs that represent the parameters passed to CloudFormation when this nested stack is created.
         *                   Each parameter has a name corresponding
         *                   to a parameter defined in the embedded template and a value representing
         *                   the value that you want to set for the parameter.
         *                   <p>
         *                   The nested stack construct will automatically synthesize parameters in order
         *                   to bind references from the parent stack(s) into the nested stack.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder parameters(java.util.Map<java.lang.String, java.lang.String> parameters) {
            this.parameters = parameters;
            return this;
        }

        /**
         * Sets the value of {@link NestedStackProps#getTimeout}
         * @param timeout The length of time that CloudFormation waits for the nested stack to reach the CREATE_COMPLETE state.
         *                When CloudFormation detects that the nested stack has reached the
         *                CREATE_COMPLETE state, it marks the nested stack resource as
         *                CREATE_COMPLETE in the parent stack and resumes creating the parent stack.
         *                If the timeout period expires before the nested stack reaches
         *                CREATE_COMPLETE, CloudFormation marks the nested stack as failed and rolls
         *                back both the nested stack and parent stack.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder timeout(software.amazon.awscdk.core.Duration timeout) {
            this.timeout = timeout;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NestedStackProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NestedStackProps build() {
            return new Jsii$Proxy(notifications, parameters, timeout);
        }
    }

    /**
     * An implementation for {@link NestedStackProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NestedStackProps {
        private final java.util.List<software.amazon.awscdk.services.sns.ITopic> notifications;
        private final java.util.Map<java.lang.String, java.lang.String> parameters;
        private final software.amazon.awscdk.core.Duration timeout;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.notifications = this.jsiiGet("notifications", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sns.ITopic.class)));
            this.parameters = this.jsiiGet("parameters", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.timeout = this.jsiiGet("timeout", software.amazon.awscdk.core.Duration.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.util.List<software.amazon.awscdk.services.sns.ITopic> notifications, final java.util.Map<java.lang.String, java.lang.String> parameters, final software.amazon.awscdk.core.Duration timeout) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.notifications = notifications;
            this.parameters = parameters;
            this.timeout = timeout;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.sns.ITopic> getNotifications() {
            return this.notifications;
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.String> getParameters() {
            return this.parameters;
        }

        @Override
        public software.amazon.awscdk.core.Duration getTimeout() {
            return this.timeout;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNotifications() != null) {
                data.set("notifications", om.valueToTree(this.getNotifications()));
            }
            if (this.getParameters() != null) {
                data.set("parameters", om.valueToTree(this.getParameters()));
            }
            if (this.getTimeout() != null) {
                data.set("timeout", om.valueToTree(this.getTimeout()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudformation.NestedStackProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NestedStackProps.Jsii$Proxy that = (NestedStackProps.Jsii$Proxy) o;

            if (this.notifications != null ? !this.notifications.equals(that.notifications) : that.notifications != null) return false;
            if (this.parameters != null ? !this.parameters.equals(that.parameters) : that.parameters != null) return false;
            return this.timeout != null ? this.timeout.equals(that.timeout) : that.timeout == null;
        }

        @Override
        public int hashCode() {
            int result = this.notifications != null ? this.notifications.hashCode() : 0;
            result = 31 * result + (this.parameters != null ? this.parameters.hashCode() : 0);
            result = 31 * result + (this.timeout != null ? this.timeout.hashCode() : 0);
            return result;
        }
    }
}

==> cloudformation-1.104.0-sources.jar: software/amazon/awscdk/services/cloudformation/NestedStackProps.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * (deprecated) Initialization props for the `NestedStack` construct.
 * <p>
 * @deprecated use core.NestedStackProps instead
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:08.329Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.NestedStackProps")
@software.amazon.jsii.Jsii.Proxy(NestedStackProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface NestedStackProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) The Simple Notification Service (SNS) topics to publish stack related events.
     * <p>
     * Default: - notifications are not sent for this stack.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.sns.ITopic> getNotifications() {
        return null;
    }

    /**
     * (deprecated) The set value pairs that represent the parameters passed to CloudFormation when this nested stack is created.
     * <p>
     * Each parameter has a name corresponding
     * to a parameter defined in the embedded template and a value representing
     * the value that you want to set for the parameter.
     * <p>
     * The nested stack construct will automatically synthesize parameters in order
     * to bind references from the parent stack(s) into the nested stack.
     * <p>
     * Default: - no user-defined parameters are passed to the nested stack
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getParameters() {
        return null;
    }

    /**
     * (deprecated) The length of time that CloudFormation waits for the nested stack to reach the CREATE_COMPLETE state.
     * <p>
     * When CloudFormation detects that the nested stack has reached the
     * CREATE_COMPLETE state, it marks the nested stack resource as
     * CREATE_COMPLETE in the parent stack and resumes creating the parent stack.
     * If the timeout period expires before the nested stack reaches
     * CREATE_COMPLETE, CloudFormation marks the nested stack as failed and rolls
     * back both the nested stack and parent stack.
     * <p>
     * Default: - no timeout
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getTimeout() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NestedStackProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NestedStackProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<NestedStackProps> {
        private java.util.List<software.amazon.awscdk.services.sns.ITopic> notifications;
        private java.util.Map<java.lang.String, java.lang.String> parameters;
        private software.amazon.awscdk.core.Duration timeout;

        /**
         * Sets the value of {@link NestedStackProps#getNotifications}
         * @param notifications The Simple Notification Service (SNS) topics to publish stack related events.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @SuppressWarnings("unchecked")
        public Builder notifications(java.util.List<? extends software.amazon.awscdk.services.sns.ITopic> notifications) {
            this.notifications = (java.util.List<software.amazon.awscdk.services.sns.ITopic>)notifications;
            return this;
        }

        /**
         * Sets the value of {@link NestedStackProps#getParameters}
         * @param parameters The set value pairs that represent the parameters passed to CloudFormation when this nested stack is created.
         *                   Each parameter has a name corresponding
         *                   to a parameter defined in the embedded template and a value representing
         *                   the value that you want to set for the parameter.
         *                   <p>
         *                   The nested stack construct will automatically synthesize parameters in order
         *                   to bind references from the parent stack(s) into the nested stack.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder parameters(java.util.Map<java.lang.String, java.lang.String> parameters) {
            this.parameters = parameters;
            return this;
        }

        /**
         * Sets the value of {@link NestedStackProps#getTimeout}
         * @param timeout The length of time that CloudFormation waits for the nested stack to reach the CREATE_COMPLETE state.
         *                When CloudFormation detects that the nested stack has reached the
         *                CREATE_COMPLETE state, it marks the nested stack resource as
         *                CREATE_COMPLETE in the parent stack and resumes creating the parent stack.
         *                If the timeout period expires before the nested stack reaches
         *                CREATE_COMPLETE, CloudFormation marks the nested stack as failed and rolls
         *                back both the nested stack and parent stack.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder timeout(software.amazon.awscdk.core.Duration timeout) {
            this.timeout = timeout;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NestedStackProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public NestedStackProps build() {
            return new Jsii$Proxy(notifications, parameters, timeout);
        }
    }

    /**
     * An implementation for {@link NestedStackProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NestedStackProps {
        private final java.util.List<software.amazon.awscdk.services.sns.ITopic> notifications;
        private final java.util.Map<java.lang.String, java.lang.String> parameters;
        private final software.amazon.awscdk.core.Duration timeout;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.notifications = software.amazon.jsii.Kernel.get(this, "notifications", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sns.ITopic.class)));
            this.parameters = software.amazon.jsii.Kernel.get(this, "parameters", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.timeout = software.amazon.jsii.Kernel.get(this, "timeout", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.util.List<? extends software.amazon.awscdk.services.sns.ITopic> notifications, final java.util.Map<java.lang.String, java.lang.String> parameters, final software.amazon.awscdk.core.Duration timeout) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.notifications = (java.util.List<software.amazon.awscdk.services.sns.ITopic>)notifications;
            this.parameters = parameters;
            this.timeout = timeout;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.sns.ITopic> getNotifications() {
            return this.notifications;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getParameters() {
            return this.parameters;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getTimeout() {
            return this.timeout;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNotifications() != null) {
                data.set("notifications", om.valueToTree(this.getNotifications()));
            }
            if (this.getParameters() != null) {
                data.set("parameters", om.valueToTree(this.getParameters()));
            }
            if (this.getTimeout() != null) {
                data.set("timeout", om.valueToTree(this.getTimeout()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudformation.NestedStackProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NestedStackProps.Jsii$Proxy that = (NestedStackProps.Jsii$Proxy) o;

            if (this.notifications != null ? !this.notifications.equals(that.notifications) : that.notifications != null) return false;
            if (this.parameters != null ? !this.parameters.equals(that.parameters) : that.parameters != null) return false;
            return this.timeout != null ? this.timeout.equals(that.timeout) : that.timeout == null;
        }

        @Override
        public final int hashCode() {
            int result = this.notifications != null ? this.notifications.hashCode() : 0;
            result = 31 * result + (this.parameters != null ? this.parameters.hashCode() : 0);
            result = 31 * result + (this.timeout != null ? this.timeout.hashCode() : 0);
            return result;
        }
    }
}
